@@ -139,13 +139,6 @@ QML_DECLARE_TYPE(QScatterSeries)
 QML_DECLARE_TYPE(QSplineSeries)
 QML_DECLARE_TYPE(QStackedBarSeries)
 
-static void initResources()
-{
-#ifdef QT_STATIC
-    Q_INIT_RESOURCE(qmake_QtCharts);
-#endif
-}
-
 QT_CHARTS_BEGIN_NAMESPACE
 
 class QtChartsQml2Plugin : public QQmlExtensionPlugin
@@ -155,7 +148,7 @@ class QtChartsQml2Plugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID QQmlExtensionInterface_iid)
 
 public:
-    QtChartsQml2Plugin(QObject *parent = 0) : QQmlExtensionPlugin(parent) { initResources(); }
+    QtChartsQml2Plugin(QObject *parent = 0) : QQmlExtensionPlugin(parent) { }
     virtual void registerTypes(const char *uri)
     {
         Q_ASSERT(QLatin1String(uri) == QLatin1String("QtCharts"));
@@ -350,6 +343,9 @@ public:
             QLatin1String("Trying to create uncreatable: CandlestickModelMapper."));
         qmlRegisterType<QHCandlestickModelMapper>(uri, 2, 2, "HCandlestickModelMapper");
         qmlRegisterType<QVCandlestickModelMapper>(uri, 2, 2, "VCandlestickModelMapper");
+
+        // QtCharts 2.3
+        qmlRegisterType<QValueAxis, 1>(uri, 2, 3, "ValueAxis");
     }
 
 };
